# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegistrationCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkImageRegistrationMethodPython
else:
    import _itkImageRegistrationMethodPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkInterpolateImageFunctionPython
import itk.itkRGBAPixelPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkRGBPixelPython
import itk.itkImageFunctionBasePython
import itk.itkFunctionBasePython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkArrayPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkOptimizerParametersPython
import itk.itkImageToImageMetricPython
import itk.itkTransformBasePython
import itk.itkVariableLengthVectorPython
import itk.itkDiffusionTensor3DPython
import itk.itkArray2DPython
import itk.ITKCostFunctionsPython
import itk.itkCostFunctionPython
import itk.vnl_least_squares_functionPython
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.itkSpatialObjectBasePython
import itk.itkSpatialObjectPropertyPython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython
import itk.itkVectorContainerPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.ITKOptimizersBasePython

def itkImageRegistrationMethodIF2IF2_New():
    return itkImageRegistrationMethodIF2IF2.New()

class itkImageRegistrationMethodIF2IF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageRegistrationMethodIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageRegistrationMethodIF2IF2_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageRegistrationMethodIF2IF2_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_Clone(self)

    def SetFixedImage(self, fixedImage):
        r"""
        SetFixedImage(self, fixedImage)

        Parameters
        ----------
        fixedImage: itkImageF2 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetFixedImage(self, fixedImage)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetFixedImage(self)

    def SetMovingImage(self, movingImage):
        r"""
        SetMovingImage(self, movingImage)

        Parameters
        ----------
        movingImage: itkImageF2 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetMovingImage(self, movingImage)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIF2IF2 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIF2IF2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIF2IF2
        GetMetric(self) -> itkImageToImageMetricIF2IF2
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetMetric(self, *args)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF2D *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF2D"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF2D
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetInterpolator(self, *args)

    def SetInitialTransformParameters(self, param):
        r"""
        SetInitialTransformParameters(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetInitialTransformParameters(self, param)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetInitialTransformParameters(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetLastTransformParameters(self)

    def SetFixedImageRegion(self, region):
        r"""
        SetFixedImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetFixedImageRegion(self, region)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetFixedImageRegion(self)

    def GetFixedImageRegionDefined(self):
        r"""GetFixedImageRegionDefined(self) -> bool"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetFixedImageRegionDefined(self)

    def SetFixedImageRegionDefined(self, _arg):
        r"""
        SetFixedImageRegionDefined(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_SetFixedImageRegionDefined(self, _arg)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_Initialize(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD22"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_GetOutput(self)
    __swig_destroy__ = _itkImageRegistrationMethodPython.delete_itkImageRegistrationMethodIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageRegistrationMethodIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageRegistrationMethodIF2IF2

        Create a new object of the class itkImageRegistrationMethodIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageRegistrationMethodIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageRegistrationMethodIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageRegistrationMethodIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageRegistrationMethodIF2IF2 in _itkImageRegistrationMethodPython:
_itkImageRegistrationMethodPython.itkImageRegistrationMethodIF2IF2_swigregister(itkImageRegistrationMethodIF2IF2)

def itkImageRegistrationMethodIF3IF3_New():
    return itkImageRegistrationMethodIF3IF3.New()

class itkImageRegistrationMethodIF3IF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageRegistrationMethodIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageRegistrationMethodIF3IF3_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageRegistrationMethodIF3IF3_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_Clone(self)

    def SetFixedImage(self, fixedImage):
        r"""
        SetFixedImage(self, fixedImage)

        Parameters
        ----------
        fixedImage: itkImageF3 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetFixedImage(self, fixedImage)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetFixedImage(self)

    def SetMovingImage(self, movingImage):
        r"""
        SetMovingImage(self, movingImage)

        Parameters
        ----------
        movingImage: itkImageF3 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetMovingImage(self, movingImage)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIF3IF3 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIF3IF3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIF3IF3
        GetMetric(self) -> itkImageToImageMetricIF3IF3
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetMetric(self, *args)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIF3D *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIF3D"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIF3D
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetInterpolator(self, *args)

    def SetInitialTransformParameters(self, param):
        r"""
        SetInitialTransformParameters(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetInitialTransformParameters(self, param)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetInitialTransformParameters(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetLastTransformParameters(self)

    def SetFixedImageRegion(self, region):
        r"""
        SetFixedImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetFixedImageRegion(self, region)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetFixedImageRegion(self)

    def GetFixedImageRegionDefined(self):
        r"""GetFixedImageRegionDefined(self) -> bool"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetFixedImageRegionDefined(self)

    def SetFixedImageRegionDefined(self, _arg):
        r"""
        SetFixedImageRegionDefined(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_SetFixedImageRegionDefined(self, _arg)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_Initialize(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD33"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_GetOutput(self)
    __swig_destroy__ = _itkImageRegistrationMethodPython.delete_itkImageRegistrationMethodIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageRegistrationMethodIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageRegistrationMethodIF3IF3

        Create a new object of the class itkImageRegistrationMethodIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageRegistrationMethodIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageRegistrationMethodIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageRegistrationMethodIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageRegistrationMethodIF3IF3 in _itkImageRegistrationMethodPython:
_itkImageRegistrationMethodPython.itkImageRegistrationMethodIF3IF3_swigregister(itkImageRegistrationMethodIF3IF3)

def itkImageRegistrationMethodISS2ISS2_New():
    return itkImageRegistrationMethodISS2ISS2.New()

class itkImageRegistrationMethodISS2ISS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageRegistrationMethodISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageRegistrationMethodISS2ISS2_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageRegistrationMethodISS2ISS2_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_Clone(self)

    def SetFixedImage(self, fixedImage):
        r"""
        SetFixedImage(self, fixedImage)

        Parameters
        ----------
        fixedImage: itkImageSS2 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetFixedImage(self, fixedImage)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetFixedImage(self)

    def SetMovingImage(self, movingImage):
        r"""
        SetMovingImage(self, movingImage)

        Parameters
        ----------
        movingImage: itkImageSS2 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetMovingImage(self, movingImage)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricISS2ISS2 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricISS2ISS2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricISS2ISS2
        GetMetric(self) -> itkImageToImageMetricISS2ISS2
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetMetric(self, *args)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS2D *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS2D"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS2D
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetInterpolator(self, *args)

    def SetInitialTransformParameters(self, param):
        r"""
        SetInitialTransformParameters(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetInitialTransformParameters(self, param)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetInitialTransformParameters(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetLastTransformParameters(self)

    def SetFixedImageRegion(self, region):
        r"""
        SetFixedImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetFixedImageRegion(self, region)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetFixedImageRegion(self)

    def GetFixedImageRegionDefined(self):
        r"""GetFixedImageRegionDefined(self) -> bool"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetFixedImageRegionDefined(self)

    def SetFixedImageRegionDefined(self, _arg):
        r"""
        SetFixedImageRegionDefined(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_SetFixedImageRegionDefined(self, _arg)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_Initialize(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD22"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_GetOutput(self)
    __swig_destroy__ = _itkImageRegistrationMethodPython.delete_itkImageRegistrationMethodISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageRegistrationMethodISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageRegistrationMethodISS2ISS2

        Create a new object of the class itkImageRegistrationMethodISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageRegistrationMethodISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageRegistrationMethodISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageRegistrationMethodISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageRegistrationMethodISS2ISS2 in _itkImageRegistrationMethodPython:
_itkImageRegistrationMethodPython.itkImageRegistrationMethodISS2ISS2_swigregister(itkImageRegistrationMethodISS2ISS2)

def itkImageRegistrationMethodISS3ISS3_New():
    return itkImageRegistrationMethodISS3ISS3.New()

class itkImageRegistrationMethodISS3ISS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageRegistrationMethodISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageRegistrationMethodISS3ISS3_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageRegistrationMethodISS3ISS3_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_Clone(self)

    def SetFixedImage(self, fixedImage):
        r"""
        SetFixedImage(self, fixedImage)

        Parameters
        ----------
        fixedImage: itkImageSS3 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetFixedImage(self, fixedImage)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetFixedImage(self)

    def SetMovingImage(self, movingImage):
        r"""
        SetMovingImage(self, movingImage)

        Parameters
        ----------
        movingImage: itkImageSS3 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetMovingImage(self, movingImage)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricISS3ISS3 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricISS3ISS3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricISS3ISS3
        GetMetric(self) -> itkImageToImageMetricISS3ISS3
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetMetric(self, *args)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionISS3D *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionISS3D"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        GetInterpolator(self) -> itkInterpolateImageFunctionISS3D
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetInterpolator(self, *args)

    def SetInitialTransformParameters(self, param):
        r"""
        SetInitialTransformParameters(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetInitialTransformParameters(self, param)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetInitialTransformParameters(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetLastTransformParameters(self)

    def SetFixedImageRegion(self, region):
        r"""
        SetFixedImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetFixedImageRegion(self, region)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetFixedImageRegion(self)

    def GetFixedImageRegionDefined(self):
        r"""GetFixedImageRegionDefined(self) -> bool"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetFixedImageRegionDefined(self)

    def SetFixedImageRegionDefined(self, _arg):
        r"""
        SetFixedImageRegionDefined(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_SetFixedImageRegionDefined(self, _arg)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_Initialize(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD33"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_GetOutput(self)
    __swig_destroy__ = _itkImageRegistrationMethodPython.delete_itkImageRegistrationMethodISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageRegistrationMethodISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageRegistrationMethodISS3ISS3

        Create a new object of the class itkImageRegistrationMethodISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageRegistrationMethodISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageRegistrationMethodISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageRegistrationMethodISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageRegistrationMethodISS3ISS3 in _itkImageRegistrationMethodPython:
_itkImageRegistrationMethodPython.itkImageRegistrationMethodISS3ISS3_swigregister(itkImageRegistrationMethodISS3ISS3)

def itkImageRegistrationMethodIUC2IUC2_New():
    return itkImageRegistrationMethodIUC2IUC2.New()

class itkImageRegistrationMethodIUC2IUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageRegistrationMethodIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageRegistrationMethodIUC2IUC2_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageRegistrationMethodIUC2IUC2_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_Clone(self)

    def SetFixedImage(self, fixedImage):
        r"""
        SetFixedImage(self, fixedImage)

        Parameters
        ----------
        fixedImage: itkImageUC2 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetFixedImage(self, fixedImage)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetFixedImage(self)

    def SetMovingImage(self, movingImage):
        r"""
        SetMovingImage(self, movingImage)

        Parameters
        ----------
        movingImage: itkImageUC2 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetMovingImage(self, movingImage)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIUC2IUC2 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIUC2IUC2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIUC2IUC2
        GetMetric(self) -> itkImageToImageMetricIUC2IUC2
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetMetric(self, *args)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD22"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD22
        GetTransform(self) -> itkTransformD22
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC2D *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC2D"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetInterpolator(self, *args)

    def SetInitialTransformParameters(self, param):
        r"""
        SetInitialTransformParameters(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetInitialTransformParameters(self, param)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetInitialTransformParameters(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetLastTransformParameters(self)

    def SetFixedImageRegion(self, region):
        r"""
        SetFixedImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetFixedImageRegion(self, region)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion2"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetFixedImageRegion(self)

    def GetFixedImageRegionDefined(self):
        r"""GetFixedImageRegionDefined(self) -> bool"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetFixedImageRegionDefined(self)

    def SetFixedImageRegionDefined(self, _arg):
        r"""
        SetFixedImageRegionDefined(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_SetFixedImageRegionDefined(self, _arg)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_Initialize(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD22"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_GetOutput(self)
    __swig_destroy__ = _itkImageRegistrationMethodPython.delete_itkImageRegistrationMethodIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageRegistrationMethodIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageRegistrationMethodIUC2IUC2

        Create a new object of the class itkImageRegistrationMethodIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageRegistrationMethodIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageRegistrationMethodIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageRegistrationMethodIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageRegistrationMethodIUC2IUC2 in _itkImageRegistrationMethodPython:
_itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC2IUC2_swigregister(itkImageRegistrationMethodIUC2IUC2)

def itkImageRegistrationMethodIUC3IUC3_New():
    return itkImageRegistrationMethodIUC3IUC3.New()

class itkImageRegistrationMethodIUC3IUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageRegistrationMethodIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageRegistrationMethodIUC3IUC3_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageRegistrationMethodIUC3IUC3_Pointer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_Clone(self)

    def SetFixedImage(self, fixedImage):
        r"""
        SetFixedImage(self, fixedImage)

        Parameters
        ----------
        fixedImage: itkImageUC3 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetFixedImage(self, fixedImage)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetFixedImage(self)

    def SetMovingImage(self, movingImage):
        r"""
        SetMovingImage(self, movingImage)

        Parameters
        ----------
        movingImage: itkImageUC3 const *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetMovingImage(self, movingImage)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetMovingImage(self)

    def SetOptimizer(self, _arg):
        r"""
        SetOptimizer(self, _arg)

        Parameters
        ----------
        _arg: itkSingleValuedNonLinearOptimizer *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetOptimizer(self, _arg)

    def GetModifiableOptimizer(self):
        r"""GetModifiableOptimizer(self) -> itkSingleValuedNonLinearOptimizer"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetModifiableOptimizer(self)

    def GetOptimizer(self, *args):
        r"""
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        GetOptimizer(self) -> itkSingleValuedNonLinearOptimizer
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetOptimizer(self, *args)

    def SetMetric(self, _arg):
        r"""
        SetMetric(self, _arg)

        Parameters
        ----------
        _arg: itkImageToImageMetricIUC3IUC3 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetMetric(self, _arg)

    def GetModifiableMetric(self):
        r"""GetModifiableMetric(self) -> itkImageToImageMetricIUC3IUC3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetModifiableMetric(self)

    def GetMetric(self, *args):
        r"""
        GetMetric(self) -> itkImageToImageMetricIUC3IUC3
        GetMetric(self) -> itkImageToImageMetricIUC3IUC3
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetMetric(self, *args)

    def SetTransform(self, _arg):
        r"""
        SetTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetTransform(self, _arg)

    def GetModifiableTransform(self):
        r"""GetModifiableTransform(self) -> itkTransformD33"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetModifiableTransform(self)

    def GetTransform(self, *args):
        r"""
        GetTransform(self) -> itkTransformD33
        GetTransform(self) -> itkTransformD33
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetTransform(self, *args)

    def SetInterpolator(self, _arg):
        r"""
        SetInterpolator(self, _arg)

        Parameters
        ----------
        _arg: itkInterpolateImageFunctionIUC3D *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetInterpolator(self, _arg)

    def GetModifiableInterpolator(self):
        r"""GetModifiableInterpolator(self) -> itkInterpolateImageFunctionIUC3D"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetModifiableInterpolator(self)

    def GetInterpolator(self, *args):
        r"""
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D
        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetInterpolator(self, *args)

    def SetInitialTransformParameters(self, param):
        r"""
        SetInitialTransformParameters(self, param)

        Parameters
        ----------
        param: itkOptimizerParametersD const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetInitialTransformParameters(self, param)

    def GetInitialTransformParameters(self):
        r"""GetInitialTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetInitialTransformParameters(self)

    def GetLastTransformParameters(self):
        r"""GetLastTransformParameters(self) -> itkOptimizerParametersD"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetLastTransformParameters(self)

    def SetFixedImageRegion(self, region):
        r"""
        SetFixedImageRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion3 const &

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetFixedImageRegion(self, region)

    def GetFixedImageRegion(self):
        r"""GetFixedImageRegion(self) -> itkImageRegion3"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetFixedImageRegion(self)

    def GetFixedImageRegionDefined(self):
        r"""GetFixedImageRegionDefined(self) -> bool"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetFixedImageRegionDefined(self)

    def SetFixedImageRegionDefined(self, _arg):
        r"""
        SetFixedImageRegionDefined(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_SetFixedImageRegionDefined(self, _arg)

    def Initialize(self):
        r"""Initialize(self)"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_Initialize(self)

    def GetOutput(self):
        r"""GetOutput(self) -> itkDataObjectDecoratorTD33"""
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_GetOutput(self)
    __swig_destroy__ = _itkImageRegistrationMethodPython.delete_itkImageRegistrationMethodIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageRegistrationMethodIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageRegistrationMethodIUC3IUC3

        Create a new object of the class itkImageRegistrationMethodIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageRegistrationMethodIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageRegistrationMethodIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageRegistrationMethodIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageRegistrationMethodIUC3IUC3 in _itkImageRegistrationMethodPython:
_itkImageRegistrationMethodPython.itkImageRegistrationMethodIUC3IUC3_swigregister(itkImageRegistrationMethodIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def image_registration_method(*args,  fixed_image: itkt.Image=..., moving_image: itkt.Image=..., optimizer=..., metric=..., transform: itkt.Transform=..., interpolator: itkt.InterpolateImageFunction=..., initial_transform_parameters=..., fixed_image_region: itkt.ImageRegion=..., fixed_image_region_defined: bool=...,**kwargs):
    """Functional interface for ImageRegistrationMethod"""
    import itk

    kwarg_typehints = { 'fixed_image':fixed_image,'moving_image':moving_image,'optimizer':optimizer,'metric':metric,'transform':transform,'interpolator':interpolator,'initial_transform_parameters':initial_transform_parameters,'fixed_image_region':fixed_image_region,'fixed_image_region_defined':fixed_image_region_defined }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ImageRegistrationMethod.New(*args, **kwargs)

    return instance.__internal_call__()

def image_registration_method_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKRegistrationCommon.ImageRegistrationMethod
    image_registration_method.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    image_registration_method.__doc__ = filter_object.__doc__



